//
//  SwiftUIView.swift
//  UIKitComponents
//
//  Created by User on 26.05.2025.
//

import SwiftUI

public struct CustomMainButtonView: View {
    
    let title: String //Название кнопки
    let fill: Bool // Закрашена ли
    let size: SizeButton // размер кнопки
    let tetriary: Bool // состояние кнопки
    let disactive: Bool // активна ли кнопка
    let action: () -> () // действие кнопки
    
    private var buttonSize: CGFloat {
        switch size {
        case .large:
            return 17
        case .chips:
            return 15
        case .small:
            return 14
        }
    }
    
    private var buttonHeight: CGFloat {
        switch size {
        case .large:
            return 56
        case .chips:
            return 48
        case .small:
            return 40
        }
    }
    
    private var buttonTextColor: Color {
        if tetriary {
            return Color("hex#2D2C2C", bundle: .module)
        } else if size == .chips && disactive {
            return Color("hex#7E7E9A", bundle: .module)
        }
        else {
            return !fill ? Color.white : Color("hex#1A6FEE", bundle: .module)
        }
    }
    
    private var buttonColor: Color {
        if tetriary {
            return Color("hex#F5F5F9", bundle: .module)
        } else if disactive {
            return Color("hex#C9D4FB", bundle: .module)
        }
        else {
            return !fill ? Color("hex#1A6FEE", bundle: .module) : Color.white
        }
    }
    
    private var buttonWeight: CGFloat {
        size == .chips ? 129 : 96
    }
    
    public init(title: String, fill: Bool = false, size: SizeButton = .large, tetriary: Bool = false, disactive: Bool = false, action: @escaping () -> Void) {
        self.title = title
        self.fill = fill
        self.size = size
        self.tetriary = tetriary
        self.disactive = disactive
        self.action = action
    }
    
    public var body: some View {
        if size == .large {
            Button {
                action()
            } label: {
                Text(title)
                    .frame(maxWidth: .infinity)
                    .frame(height: buttonHeight)
                    .robotoFlex(size: buttonSize, font: .bold)
                    .foregroundStyle(buttonTextColor)
                    .background(buttonColor)
                    .cornerRadius(10)
                    .overlay {
                        if fill {
                            RoundedRectangle(cornerRadius: 10)
                                .stroke(lineWidth: 1)
                                .foregroundStyle(Color("hex#1A6FEE", bundle: .module))
                        }
                    }
            }.disabled(disactive)
            
        } else if size == .chips || size == .small {
            Button {
                action()
            } label: {
                Text(title)
                    .frame(width: buttonWeight)
                    .frame(height: buttonHeight)
                    .robotoFlex(size: buttonSize, font: .bold)
                    .foregroundStyle(buttonTextColor)
                    .background(buttonColor)
                    .cornerRadius(10)
                    .overlay {
                        if fill {
                            RoundedRectangle(cornerRadius: 10)
                                .stroke(lineWidth: 1)
                                .foregroundStyle(Color("hex#1A6FEE", bundle: .module))
                        }
                    }
            }.disabled(disactive)
        }

    }
}

#Preview {
    CustomMainButtonView(title: "Подтвердить") {
        print("jopa")
    }
}
