//
//  SwiftUIView.swift
//  UIKitComponents
//
//  Created by User on 26.05.2025.
//

import SwiftUI

public struct CardPrimaryView: View {
    
    let title: String //Название карточки
    let subtitle: String // Описание
    let price: Int // цена
    let status: Bool // в корзине или нет
    
    let titleForButton: String
    let action: () -> ()
    
    public init(title: String, subtitle: String = "", price: Int = 0, status: Bool = false, titleForButton: String = "Добавить", action: @escaping () -> Void) {
        self.title = title
        self.subtitle = subtitle
        self.price = price
        self.status = status
        self.titleForButton = titleForButton
        self.action = action
    }
    
    public var body: some View {
        ZStack(alignment: .leading) {
            Color.white.ignoresSafeArea()
            VStack(alignment: .leading) {
                    Text(title)
                        .multilineTextAlignment(.leading)
                        .robotoFlex(size: 16, font: .medium)
                        .tracking(0.32)
                        .lineSpacing(8)
                        .padding(.horizontal, 16)
                        .padding(.top, 16)
                Spacer()
                HStack {
                    VStack(alignment: .leading, spacing:0){
                        Text(subtitle)
                            .tracking(0)
                            .lineSpacing(20)
                            .robotoFlex(size: 14, font: .semibold)
                            .padding(.bottom, 4)
                            .foregroundStyle(Color("hex#939396", bundle: .module))
                        if price > 0 {
                            Text("\(price) ₽")
                                .robotoFlex(size: 17, font: .semibold)
                        }
                    }.padding(.horizontal, 16)
                    Spacer()
                    CustomMainButtonView(title: titleForButton, fill: status, size: .small) {
                        print(status)
                    }
                    .padding(16)
                }
                
            }
        }     .frame(maxWidth: .infinity)
            .frame(height: 136)
                .cornerRadius(12)
                .shadow(color: Color("hex#E4E8F599", bundle: .module), radius: 20)
                .overlay {
                    RoundedRectangle(cornerRadius: 12)
                        .stroke(lineWidth: 1)
                        .foregroundStyle(Color("hex#F4F4F4", bundle: .module))
                }
    }
}

#Preview {
    CardPrimaryView(title: "Рубашка Воскресенье для машинного вязания", subtitle: "Мужская одежда", price: 10, status: true) {
        
    }
}
