//
//  SwiftUIView.swift
//  UIKitComponents
//
//  Created by User on 26.05.2025.
//

import SwiftUI

public struct CardProjectView: View {
    
    let title: String //Название карточки
    let subtitle: String // days

    let action: () -> ()
    
    public init(title: String, subtitle: String = "", action: @escaping () -> Void) {
        self.title = title
        self.subtitle = subtitle
        self.action = action
    }
    
    public var body: some View {
        ZStack(alignment: .leading) {
            Color.white.ignoresSafeArea()
            VStack(alignment: .leading) {
                HStack {
                    Text(title)
                        .multilineTextAlignment(.leading)
                        .robotoFlex(size: 16, font: .medium)
                        .tracking(0.32)
                        .lineSpacing(8)
                        .padding(.horizontal, 16)
                        .padding(.top, 16)
                }
                Spacer()
                HStack {
                    VStack(alignment: .leading, spacing:0){
                        Text(subtitle)
                            .robotoFlex(size: 14, font: .bold)
                            .foregroundStyle(Color("hex#939396", bundle: .module))
                    }.padding(.horizontal, 16)
                    Spacer()
                    CustomMainButtonView(title: "Открыть", size: .small) {
                        //
                    }.padding(16)
                }
                
            }
        }
        .frame(maxWidth: .infinity)
        .frame(height: 136)
            .cornerRadius(12)
            .shadow(color: Color("hex#E4E8F599", bundle: .module), radius: 20)
            .overlay {
                RoundedRectangle(cornerRadius: 12)
                    .stroke(lineWidth: 1)
                    .foregroundStyle(Color("hex#F4F4F4", bundle: .module))
            }
    }
}

#Preview {
    CardProjectView(title: "Мой первый прокт", subtitle: "2 lyz") {
        //
    }
}
