//
//  SwiftUIView.swift
//  UIKitComponents
//
//  Created by User on 26.05.2025.
//

import SwiftUI

public struct CustomTextField: View {
    
    //MARK: Properties
    
    let title: String //Название textfield
    let titleKey: String //titleKey который отображается в textfield
    let error: Bool // status error
    let errorText: String
    let security: Bool // securityField
    @FocusState var isFocused: Bool //active textfield
    @Binding var text: String //text for textField
    @State var eye: Bool = false //Видимость security field
    
    //Цвет border
    private var colorStroke: String {
        if isFocused { return "hex#2254F580" }
        if error { return "hex#FD3535" }
        if !text.isEmpty { return "hex#B8C1CC" }
        else { return "hex#EBEBEB" }
    }
    
    //MARK: Init
    
    public init(title: String = "", titleKey: String, error: Bool = false, errorText: String = "", security: Bool = false, text: Binding<String>) {
        self.title = title
        self.titleKey = titleKey
        self.error = error
        self.errorText = errorText
        self.security = security
        self._text = text
    }
    
    //MARK: View
    
    public var body: some View {
        VStack(alignment: .leading){
            if !title.isEmpty {
                Text(title)
                    .robotoFlex(size: 14)
                    .foregroundStyle(Color("hex#7E7E9A", bundle: .module))
                    .tracking(0)
                    .lineSpacing(20)
            }
            ZStack {
                if security && !eye {
                    SecureField("", text: $text)
                        .padding(.horizontal, 14)
                        .frame(maxWidth: .infinity)
                        .frame(height: 48)
                        .focused($isFocused)
                        .tracking(0.32)
                        .lineSpacing(20)
                        .background(
                            RoundedRectangle(cornerRadius: 10)
                                .foregroundStyle(Color(error ? "hex#FD3535" : "hex#F5F5F9", bundle: .module))
                                .opacity(error ? 0.1 : 1)
                                .overlay(content: {
                                    RoundedRectangle(cornerRadius: 10)
                                        .stroke(lineWidth: 1)
                                        .foregroundStyle(Color(colorStroke, bundle: .module))
                                })
                        )
                } else {
                    TextField("", text: $text)
                        .padding(.horizontal, 14)
                        .frame(maxWidth: .infinity)
                        .frame(height: 48)
                        .focused($isFocused)
                        .background(
                            RoundedRectangle(cornerRadius: 10)
                                .foregroundStyle(Color(error ? "hex#FD3535" : "hex#F5F5F9", bundle: .module))
                                .opacity(error ? 0.1 : 1)
                                .overlay(content: {
                                    RoundedRectangle(cornerRadius: 10)
                                        .stroke(lineWidth: 1)
                                        .foregroundStyle(Color(colorStroke, bundle: .module))
                                })
                        )
                }
                HStack {
                    if text.isEmpty {
                        Text(titleKey)
                            .foregroundStyle(Color("hex#939396", bundle: .module))
                            .robotoFlex(size: 15)
                            .tracking(0)
                            .lineSpacing(20)
                    }
                    Spacer()
                    if !text.isEmpty {
                        if security {
                            Button {
                                eye.toggle()
                            } label: {
                                Image(!eye ? "EyeClose" : "EyeOpen", bundle: .module)
                            }
                        }
                    }
                }.padding(.horizontal, 14)
            }
            if error {
                Text("Введите ваше имя")
                    .robotoFlex(size: 14)
                    .foregroundStyle(Color("hex#FD3535", bundle: .module))
            }
        }
    }
}

#Preview {
    CustomTextField(titleKey: "",security: true , text: .constant("dwed"))
}
