//
//  SwiftUIView.swift
//  UIKitComponents
//
//  Created by User on 26.05.2025.
//

import SwiftUI

public struct SelectView: View {
    
    @State var title: String
    let variants: [String]
    
    public init(title: String, variants: [String]) {
        self.title = title
        self.variants = variants
    }
    
    public var body: some View {
        ZStack {
            Menu(content: {
                ForEach(variants, id: \.self) { variant in
                    Button(variant) {
                        title = variant
                    }
                }
                
            }, label: {
                Text("")
                    .frame(maxWidth: .infinity)
                    .frame(height: 48)
                    .cornerRadius(10)
                    .background(
                        RoundedRectangle(cornerRadius: 10)
                            .foregroundStyle(Color("hex#F5F5F9", bundle: .module))
                            .overlay(content: {
                                RoundedRectangle(cornerRadius: 10)
                                    .stroke(lineWidth: 1)
                                    .foregroundStyle(Color("hex#EBEBEB", bundle: .module))
                            })
                    )
            })
            HStack {
                Text(title)
                    .robotoFlex(size: 16)
                    .foregroundStyle(variants.contains(title) ? Color.black : (Color("hex#939396", bundle: .module)))
                    .tracking(0.32)
                    .lineSpacing(20)
                Spacer()
                Image("down", bundle: .module)
            }.padding(.horizontal, 14)
        }
    }
}

#Preview {
    SelectView(title: "Пол", variants: ["Male", "Female", "gay"])
}
